##  Leverage Deletion Scope
Deletion scope can be used to set up automatic deletion when loading data using inbound Data Processors.
For more information, see [Auto deletion with inboundProcessors](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio27587cd97a4410148028aef3419a720f__auto_deletion_with_inboundprocessors).
